/* This file is part of the Imote2 Codeloader.
 *
 * The Imote2 Codeloader is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Imote2 Codeloader is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Imote2 Codeloader. If not, see <http://www.gnu.org/licenses/>.
*/
/**
 * Main.java
 * 
 * @author Markus Engel
 * Copyright (c) 2009,2010 Networked Systems Group, University of Kaiserslautern
 */
package imote;

/** Main Class */
public class Main {
	/** program version */
	public static String VERSION = "2.2";

	/** entry point
	 *
	 * @param args command line arguments
	 */
	public static void main(String[] args) {
		Configuration config;

		System.out.println("Codeloader Version " + VERSION);

		/* read configuration from command line */
		config = new Configuration();
		try {
			config.parseCommandLine(args);
		} catch (Exception e) {
			System.err.println("Could not parse Commandline: " + e.getMessage());
			e.printStackTrace();
			return;
		}

		//config.dump();

		Role role;

		/* determine role of that instance of the program */
		if (config.getListen()) {
			/* server role */
			role = new Server();
		} else if (config.hasConnect()) {
			/* client role */
			role = new Client();
		} else {
			/* local role */
			role = new Local();
		}

		role.start(config);
	}
}
